////////////////////////////////////////////////////////////////////////////////
/*! \file       quoted_printable.h
    Header file for functions to encode and decode quoted-printable (RFC 2045)
    According to http://tools.ietf.org/html/rfc2045#section-6.7

    Version:    1.0                       <br>
    Copyright:  Orjan Westin 2011         <br>
    Licence:    BSD (see EOF comment)     <br>
    Contact:    orjan@coolcowstudio.co.uk <br>
    Download:   http://coolcowstudio.co.uk/source/cpp/coding.zip
*///////////////////////////////////////////////////////////////////////////////

#ifndef COCOST_QUOTED_PRINTABLE_H_
#define COCOST_QUOTED_PRINTABLE_H_

#include <string>

//! Cool Cow Studio namespace
namespace CoCoSt 
{
  //! Coding function namespace
  namespace Coding
  {
    //! Decode quoted-printable string to text
    /*  Decode standards-conformant quoted-printable string to text.
        Lenient in that lower-case hex codes are accepted, otherwise strictly
        following http://tools.ietf.org/html/rfc2045#section-6.7

        \throws std::invalid_argument input string is not legal quoted-printable

        \param qp quoted-printable text to decode
        \param text output string in which the decoded text will be entered
    */
    void qp_to_text(const std::string& qp, 
            std::string& text);

    //! Encode text ro quoted-printable
    /*  Encode text to standards-conformant quoted-printable string.
        Strictly following http://tools.ietf.org/html/rfc2045#section-6.7

        \param text input string to encode
        \param qp output string in which the encoded text will be entered
    */
    void text_to_qp(const std::string& text, 
            std::string& qp);
  }
}

#endif // COCOST_QUOTED_PRINTABLE_H_

/*

Copyright (c) 2011, Orjan Westin
All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

Redistributions of source code must retain the above copyright notice, this list
of conditions and the following disclaimer.

Redistributions in binary form must reproduce the above copyright notice, this
list of conditions and the following disclaimer in the documentation and/or
other materials provided with the distribution.

The name of the contributor(s) may be used to endorse or promote products derived
from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

*/

